# Foo

## Living Standard, 1 January 1970

This version:
  http://example.com/foo
Editor:
  Example Editor

COPYRIGHT GOES HERE

## Abstract

Testing that line numbers/highlighting works.

    [Constructor(double value, DOMString unit)]
    interface CSSUnitValue : CSSNumericValue {
        attribute double value;
        attribute DOMString unit;
        readonly attribute DOMString type;
    };

    [Constructor(double value, DOMString unit)]
    interface CSSUnitValue : CSSNumericValue {
        attribute double value;
        attribute DOMString unit;
        readonly attribute DOMString type;
    };

    [Constructor(double value, DOMString unit)]
    interface CSSUnitValue : CSSNumericValue {
        attribute double value;
        attribute DOMString unit;
        readonly attribute DOMString type;
    };

    [Constructor(double value, DOMString unit)]interface CSSUnitValue : CSSNumericValue {    attribute double value;    attribute DOMString unit;    readonly attribute DOMString type;};

    [Constructor(double value, DOMString unit)]interface CSSUnitValue : CSSNumericValue {    attribute double value;    attribute DOMString unit;    readonly attribute DOMString type;};

    [Constructor(double value, DOMString unit)]interface CSSUnitValue : CSSNumericValue {    attribute double value;    attribute DOMString unit;    readonly attribute DOMString type;};

    [Constructor(double value, DOMString unit)]interface CSSUnitValue : CSSNumericValue {    attribute double value;    attribute DOMString unit;    readonly attribute DOMString type;};

    [Constructor(double value, DOMString unit)]interface CSSUnitValue : CSSNumericValue {    attribute double value;    attribute DOMString unit;    readonly attribute DOMString type;};

    [Constructor(double value, DOMString unit)]interface CSSUnitValue : CSSNumericValue {    attribute double value;    attribute DOMString unit;    readonly attribute DOMString type;};

    [Constructor(double value, DOMString unit)]interface CSSUnitValue : CSSNumericValue {    attribute double value;    attribute DOMString unit;    readonly attribute DOMString type;};